@@ -35,15 +35,22 @@ except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import struct_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 
 from google.cloud.recommender_v1.services.recommender import pagers
 from google.cloud.recommender_v1.types import (
-    insight,
-    recommendation,
-    recommender_service,
+    insight_type_config as gcr_insight_type_config,
 )
+from google.cloud.recommender_v1.types import (
+    recommender_config as gcr_recommender_config,
+)
+from google.cloud.recommender_v1.types import insight
+from google.cloud.recommender_v1.types import insight_type_config
+from google.cloud.recommender_v1.types import recommendation
+from google.cloud.recommender_v1.types import recommender_config
+from google.cloud.recommender_v1.types import recommender_service
 
 from .transports.base import DEFAULT_CLIENT_INFO, RecommenderTransport
 from .transports.grpc import RecommenderGrpcTransport
@@ -220,6 +227,28 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
         return m.groupdict() if m else {}
 
+    @staticmethod
+    def insight_type_config_path(
+        project: str,
+        location: str,
+        insight_type: str,
+    ) -> str:
+        """Returns a fully-qualified insight_type_config string."""
+        return "projects/{project}/locations/{location}/insightTypes/{insight_type}/config".format(
+            project=project,
+            location=location,
+            insight_type=insight_type,
+        )
+
+    @staticmethod
+    def parse_insight_type_config_path(path: str) -> Dict[str, str]:
+        """Parses a insight_type_config path into its component segments."""
+        m = re.match(
+            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/insightTypes/(?P<insight_type>.+?)/config$",
+            path,
+        )
+        return m.groupdict() if m else {}
+
     @staticmethod
     def recommendation_path(
         project: str,
@@ -268,6 +297,28 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
         return m.groupdict() if m else {}
 
+    @staticmethod
+    def recommender_config_path(
+        project: str,
+        location: str,
+        recommender: str,
+    ) -> str:
+        """Returns a fully-qualified recommender_config string."""
+        return "projects/{project}/locations/{location}/recommenders/{recommender}/config".format(
+            project=project,
+            location=location,
+            recommender=recommender,
+        )
+
+    @staticmethod
+    def parse_recommender_config_path(path: str) -> Dict[str, str]:
+        """Parses a recommender_config path into its component segments."""
+        m = re.match(
+            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/recommenders/(?P<recommender>.+?)/config$",
+            path,
+        )
+        return m.groupdict() if m else {}
+
     @staticmethod
     def common_billing_account_path(
         billing_account: str,
@@ -508,6 +559,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def list_insights(
@@ -1504,6 +1556,418 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         # Done; return the response.
         return response
 
+    def get_recommender_config(
+        self,
+        request: Union[recommender_service.GetRecommenderConfigRequest, dict] = None,
+        *,
+        name: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> recommender_config.RecommenderConfig:
+        r"""Gets the requested Recommender Config. There is only
+        one instance of the config for each Recommender.
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1
+
+            def sample_get_recommender_config():
+                # Create a client
+                client = recommender_v1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1.GetRecommenderConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_recommender_config(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.recommender_v1.types.GetRecommenderConfigRequest, dict]):
+                The request object. Request for the
+                GetRecommenderConfig` method.
+            name (str):
+                Required. Name of the Recommendation Config to get.
+
+                Acceptable formats:
+
+                -  ``projects/[PROJECT_NUMBER]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID]/config``
+
+                -  ``projects/[PROJECT_ID]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID]/config``
+
+                -  ``organizations/[ORGANIZATION_ID]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID]/config``
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.recommender_v1.types.RecommenderConfig:
+                Configuration for a Recommender.
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a recommender_service.GetRecommenderConfigRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, recommender_service.GetRecommenderConfigRequest):
+            request = recommender_service.GetRecommenderConfigRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if name is not None:
+                request.name = name
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.get_recommender_config]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    def update_recommender_config(
+        self,
+        request: Union[recommender_service.UpdateRecommenderConfigRequest, dict] = None,
+        *,
+        recommender_config: gcr_recommender_config.RecommenderConfig = None,
+        update_mask: field_mask_pb2.FieldMask = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> gcr_recommender_config.RecommenderConfig:
+        r"""Updates a Recommender Config. This will create a new
+        revision of the config.
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1
+
+            def sample_update_recommender_config():
+                # Create a client
+                client = recommender_v1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1.UpdateRecommenderConfigRequest(
+                )
+
+                # Make the request
+                response = client.update_recommender_config(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.recommender_v1.types.UpdateRecommenderConfigRequest, dict]):
+                The request object. Request for the
+                `UpdateRecommenderConfig` method.
+            recommender_config (google.cloud.recommender_v1.types.RecommenderConfig):
+                Required. The RecommenderConfig to
+                update.
+
+                This corresponds to the ``recommender_config`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            update_mask (google.protobuf.field_mask_pb2.FieldMask):
+                The list of fields to be updated.
+                This corresponds to the ``update_mask`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.recommender_v1.types.RecommenderConfig:
+                Configuration for a Recommender.
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([recommender_config, update_mask])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a recommender_service.UpdateRecommenderConfigRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, recommender_service.UpdateRecommenderConfigRequest):
+            request = recommender_service.UpdateRecommenderConfigRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if recommender_config is not None:
+                request.recommender_config = recommender_config
+            if update_mask is not None:
+                request.update_mask = update_mask
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[
+            self._transport.update_recommender_config
+        ]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("recommender_config.name", request.recommender_config.name),)
+            ),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    def get_insight_type_config(
+        self,
+        request: Union[recommender_service.GetInsightTypeConfigRequest, dict] = None,
+        *,
+        name: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> insight_type_config.InsightTypeConfig:
+        r"""Gets the requested InsightTypeConfig. There is only
+        one instance of the config for each InsightType.
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1
+
+            def sample_get_insight_type_config():
+                # Create a client
+                client = recommender_v1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1.GetInsightTypeConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_insight_type_config(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.recommender_v1.types.GetInsightTypeConfigRequest, dict]):
+                The request object. Request for the
+                GetInsightTypeConfig` method.
+            name (str):
+                Required. Name of the InsightTypeConfig to get.
+
+                Acceptable formats:
+
+                -  ``projects/[PROJECT_NUMBER]/locations/global/recommenders/[INSIGHT_TYPE_ID]/config``
+
+                -  ``projects/[PROJECT_ID]/locations/global/recommenders/[INSIGHT_TYPE_ID]/config``
+
+                -  ``organizations/[ORGANIZATION_ID]/locations/global/recommenders/[INSIGHT_TYPE_ID]/config``
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.recommender_v1.types.InsightTypeConfig:
+                Configuration for an InsightType.
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a recommender_service.GetInsightTypeConfigRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, recommender_service.GetInsightTypeConfigRequest):
+            request = recommender_service.GetInsightTypeConfigRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if name is not None:
+                request.name = name
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.get_insight_type_config]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    def update_insight_type_config(
+        self,
+        request: Union[recommender_service.UpdateInsightTypeConfigRequest, dict] = None,
+        *,
+        insight_type_config: gcr_insight_type_config.InsightTypeConfig = None,
+        update_mask: field_mask_pb2.FieldMask = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> gcr_insight_type_config.InsightTypeConfig:
+        r"""Updates an InsightTypeConfig change. This will create
+        a new revision of the config.
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1
+
+            def sample_update_insight_type_config():
+                # Create a client
+                client = recommender_v1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1.UpdateInsightTypeConfigRequest(
+                )
+
+                # Make the request
+                response = client.update_insight_type_config(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.recommender_v1.types.UpdateInsightTypeConfigRequest, dict]):
+                The request object. Request for the
+                `UpdateInsightTypeConfig` method.
+            insight_type_config (google.cloud.recommender_v1.types.InsightTypeConfig):
+                Required. The InsightTypeConfig to
+                update.
+
+                This corresponds to the ``insight_type_config`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            update_mask (google.protobuf.field_mask_pb2.FieldMask):
+                The list of fields to be updated.
+                This corresponds to the ``update_mask`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.recommender_v1.types.InsightTypeConfig:
+                Configuration for an InsightType.
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([insight_type_config, update_mask])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a recommender_service.UpdateInsightTypeConfigRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, recommender_service.UpdateInsightTypeConfigRequest):
+            request = recommender_service.UpdateInsightTypeConfigRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if insight_type_config is not None:
+                request.insight_type_config = insight_type_config
+            if update_mask is not None:
+                request.update_mask = update_mask
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[
+            self._transport.update_insight_type_config
+        ]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("insight_type_config.name", request.insight_type_config.name),)
+            ),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     def __enter__(self):
         return self
 
