@@ -13,14 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from .insight import (
-    Insight,
-    InsightStateInfo,
-)
-from .insight_type_config import (
-    InsightTypeConfig,
-    InsightTypeGenerationConfig,
-)
+from .insight import Insight, InsightStateInfo
+from .insight_type_config import InsightTypeConfig, InsightTypeGenerationConfig
 from .recommendation import (
     CostProjection,
     Impact,
@@ -33,10 +27,7 @@ from .recommendation import (
     SustainabilityProjection,
     ValueMatcher,
 )
-from .recommender_config import (
-    RecommenderConfig,
-    RecommenderGenerationConfig,
-)
+from .recommender_config import RecommenderConfig, RecommenderGenerationConfig
 from .recommender_service import (
     GetInsightRequest,
     GetInsightTypeConfigRequest,
